/*
 * PWM.c
 *
 *  Created on: 2021. 3. 9.
 *      Author: User
 */

#include "PWM.h"
#include "IfxCpu.h"

#define ISR_PRIORITY_GTM_TRIG	0

IfxGtm_Tom_PwmHl PWMHlHandler;
IfxGtm_Tom_Timer PWMTimerHandler;
IfxStdIf_Timer PWMTimerInterface;
IfxStdIf_PwmHl PWMHlInterface;

#define LED                 &MODULE_P13, 0          /* LED which will be toggled in Interrupt Service Routine (ISR) */

IFX_INTERRUPT(TriggerInterrupt, 0, ISR_PRIORITY_GTM_TRIG);

void TriggerInterrupt(void) {
	IfxGtm_Tom_Timer_acknowledgeTriggerIrq(&PWMTimerHandler);

	IfxPort_togglePin(LED);
}



void PWM_Init(void) {

	IfxGtm_Tom_PwmHl_Config pwmConfig;
	IfxGtm_Tom_Timer_Config timerConfig;
	float32 gtmFrequency;
	const IfxGtm_Tom_ToutMapP cout[3] = {
			&IfxGtm_TOM1_1_TOUT11_P00_2_OUT,
			&IfxGtm_TOM1_3_TOUT13_P00_4_OUT,
			&IfxGtm_TOM1_5_TOUT15_P00_6_OUT
	};

	const IfxGtm_Tom_ToutMapP ccx[3] = {
			&IfxGtm_TOM1_2_TOUT12_P00_3_OUT,
			&IfxGtm_TOM1_4_TOUT14_P00_5_OUT,
			&IfxGtm_TOM1_6_TOUT16_P00_7_OUT
	};

	IfxGtm_enable(&MODULE_GTM);
	gtmFrequency = IfxGtm_Cmu_getModuleFrequency(&MODULE_GTM);
	IfxGtm_Cmu_setGclkFrequency(&MODULE_GTM, gtmFrequency);
	IfxGtm_Cmu_enableClocks(&MODULE_GTM, IFXGTM_CMU_CLKEN_FXCLK);
	IfxPort_setPinModeOutput(LED, IfxPort_OutputMode_pushPull, IfxPort_OutputIdx_general);  /* Set pin mode         */
	/* timer config */
	IfxGtm_Tom_Timer_initConfig(&timerConfig, &MODULE_GTM);
	timerConfig.base.frequency = 20000;
	timerConfig.base.minResolution = 0.0000001;
	timerConfig.tom = IfxGtm_Tom_1;

	timerConfig.irqModeTrigger = IfxGtm_IrqMode_pulse;
	timerConfig.base.trigger.enabled = 1;
	timerConfig.base.trigger.triggerPoint = 2500;
	timerConfig.base.trigger.isrPriority = ISR_PRIORITY_GTM_TRIG;
	timerConfig.base.trigger.isrProvider = IfxSrc_Tos_cpu0;
	timerConfig.base.trigger.outputDriver = IfxPort_PadDriver_cmosAutomotiveSpeed2;
	timerConfig.triggerOut = &IfxGtm_TOM1_7_TOUT17_P00_8_OUT;


	IfxGtm_Tom_Timer_init(&PWMTimerHandler, &timerConfig);
	IfxGtm_Tom_Timer_stdIfTimerInit(&PWMTimerInterface, &PWMTimerHandler);
	IfxGtm_Tom_Timer_run(&PWMTimerHandler);
	/* pwm config */
	IfxGtm_Tom_PwmHl_initConfig(&pwmConfig);

	pwmConfig.base.deadtime = 1.0e-6;
	pwmConfig.base.channelCount = 3;
	pwmConfig.base.ccxActiveState = Ifx_ActiveState_low;
	pwmConfig.base.coutxActiveState = Ifx_ActiveState_high;
	pwmConfig.ccx = &ccx[0];
	pwmConfig.coutx = &cout[0];
	pwmConfig.timer = &PWMTimerHandler;
	pwmConfig.tom = IfxGtm_Tom_1;

	IfxGtm_Tom_PwmHl_init(&PWMHlHandler, &pwmConfig);
	IfxGtm_Tom_PwmHl_stdIfPwmHlInit(&PWMHlInterface, &PWMHlHandler);

	IfxGtm_Trig_toVadc(&MODULE_GTM, IfxGtm_Trig_AdcGroup_0, IfxGtm_Trig_AdcTrig_1, IfxGtm_Trig_AdcTrigSource_tom1, IfxGtm_Trig_AdcTrigChannel_7);
	IfxGtm_Trig_toVadc(&MODULE_GTM, IfxGtm_Trig_AdcGroup_1, IfxGtm_Trig_AdcTrig_1, IfxGtm_Trig_AdcTrigSource_tom1, IfxGtm_Trig_AdcTrigChannel_7);
	IfxGtm_Trig_toVadc(&MODULE_GTM, IfxGtm_Trig_AdcGroup_3, IfxGtm_Trig_AdcTrig_1, IfxGtm_Trig_AdcTrigSource_tom1, IfxGtm_Trig_AdcTrigChannel_7);

	IfxGtm_Tom_PwmHl_setMode(&PWMHlHandler, Ifx_Pwm_Mode_centerAligned);

	Ifx_TimerValue tOn[3];
	tOn[0] = 2500;
	tOn[1] = 2500;
	tOn[2] = 2500;

	PWM_setDuty(tOn, 2500);
}

void PWM_setDuty(Ifx_TimerValue* tOn, Ifx_TimerValue adcTon) {

    PWMTimerInterface.disableUpdate(&PWMTimerHandler);
    PWMTimerInterface.setTrigger(&PWMTimerHandler, adcTon);
    PWMHlHandler.update(&PWMHlHandler, &tOn[0]);
    PWMTimerInterface.applyUpdate(&PWMTimerHandler);
}

Ifx_TimerValue PWM_getPeriod(void) {

	return (PWMTimerHandler.base.period);
}

Ifx_TimerValue PWM_getDeadTime(void) {

	return (PWMHlHandler.base.deadtime);
}
