/*
 * SPI.c
 *
 *  Created on: 2021. 3. 9.
 *      Author: User
 */


#include "SPI.h"

#define ISR_PRIORITY_SPI3_TX		30
#define ISR_PRIORITY_SPI3_RX		32
#define ISR_PRIORITY_SPI3_ER		0

IfxQspi_SpiMaster SPI3Handler;
IfxQspi_SpiMaster_Channel SPI3ChannelHandler;

IFX_INTERRUPT(SPI3_ISR_TX, 0, ISR_PRIORITY_SPI3_TX);
IFX_INTERRUPT(SPI3_ISR_RX, 0, ISR_PRIORITY_SPI3_RX);
IFX_INTERRUPT(SPI3_ISR_ER, 0, ISR_PRIORITY_SPI3_ER);

void SPI3_ISR_TX(void) {

	IfxCpu_enableInterrupts();
	IfxQspi_SpiMaster_isrTransmit(&SPI3Handler);
}

void SPI3_ISR_RX(void) {

	IfxCpu_enableInterrupts();
	IfxQspi_SpiMaster_isrReceive(&SPI3Handler);
}

void SPI3_ISR_ER(void) {

	IfxCpu_enableInterrupts();
	IfxQspi_SpiMaster_isrError(&SPI3Handler);
}

static void SPI3_initMasterModule(void);
static void SPI3_initMasterChannel(void);

static void SPI3_initMasterModule(void) {

	IfxQspi_SpiMaster_Config spiMasterConfig;
	IfxQspi_SpiMaster_initModuleConfig(&spiMasterConfig, &MODULE_QSPI3);

	spiMasterConfig.base.mode = SpiIf_Mode_master;

    const IfxQspi_SpiMaster_Pins qspiMasterPins = {
        &IfxQspi3_SCLK_P22_3_OUT, IfxPort_OutputMode_pushPull,          /* SCLK Pin                       (CLK)     */
        &IfxQspi3_MTSR_P22_0_OUT, IfxPort_OutputMode_pushPull,          /* MasterTransmitSlaveReceive pin (MOSI)    */
        &IfxQspi3_MRSTE_P22_1_IN, IfxPort_InputMode_noPullDevice,           /* MasterReceiveSlaveTransmit pin (MISO)    */
        IfxPort_PadDriver_cmosAutomotiveSpeed1                          /* Pad driver mode                          */
    };

    spiMasterConfig.pins = &qspiMasterPins;

    spiMasterConfig.base.txPriority = ISR_PRIORITY_SPI3_TX;
    spiMasterConfig.base.rxPriority = ISR_PRIORITY_SPI3_RX;
    spiMasterConfig.base.erPriority = ISR_PRIORITY_SPI3_ER;
    spiMasterConfig.base.isrProvider = IfxSrc_Tos_cpu0;

    IfxQspi_SpiMaster_initModule(&SPI3Handler, &spiMasterConfig);
}

static void SPI3_initMasterChannel(void) {

    IfxQspi_SpiMaster_ChannelConfig spiMasterChannelConfig;

    /* Initialize the configuration with default values */
    IfxQspi_SpiMaster_initChannelConfig(&spiMasterChannelConfig, &SPI3Handler);

    spiMasterChannelConfig.base.baudrate = 1000000;
    spiMasterChannelConfig.base.mode.dataWidth = 24;
    spiMasterChannelConfig.base.mode.shiftClock = SpiIf_ShiftClock_shiftTransmitDataOnTrailingEdge;
	spiMasterChannelConfig.base.mode.csLeadDelay     = SpiIf_SlsoTiming_0;
    spiMasterChannelConfig.base.mode.csTrailDelay    = SpiIf_SlsoTiming_1;
    spiMasterChannelConfig.base.mode.csInactiveDelay = SpiIf_SlsoTiming_7;
    /* Select the port pin for the Chip Select signal */
    const IfxQspi_SpiMaster_Output qspiSlaveSelect = {
        &IfxQspi3_SLSO12_P22_2_OUT, IfxPort_OutputMode_pushPull,
        IfxPort_PadDriver_cmosAutomotiveSpeed1
    };
    spiMasterChannelConfig.sls.output = qspiSlaveSelect;

    /* Initialize the QSPI Master channel */
    IfxQspi_SpiMaster_initChannel(&SPI3ChannelHandler, &spiMasterChannelConfig);
}

void SPI3_init(void) {

	SPI3_initMasterModule();
	SPI3_initMasterChannel();
}

void SPI3_transmit(uint32* src, uint32* dst, sint16 size) {

	IfxQspi_SpiMaster_exchange(&SPI3ChannelHandler, src, dst, size);
}
