/*
 * VADC.c
 *
 *  Created on: 2021. 3. 9.
 *      Author: User
 */

#include "VADC.h"
#include "TorqueControl.h"

#define AppVadc_SH_FREQUENCY	(120000000U)

void vadc_conversionEndGroup0(void);
//Name VADC interrupts
IFX_INTERRUPT(vadcgroup0ISR, 0, INTERRUPT_VADC_RESULT_GROUP0)
{
	vadc_conversionEndGroup0();
}

typedef struct
{
	uint8 channelIndex[9];
	uint8 used[9];
	uint16 options[9];
}AppVadc_queuedMode;

typedef struct
{
	IfxVadc_Adc		  module;
	IfxVadc_Adc_Group group[NUMBER_OF_USE_GROUP];
	AppVadc_AnalogInput_1	channel[AppVadc_ChannelCount];
}AppVadc_Kernel;

const IfxVadc_Adc_Config IfxVadc_adc_module_config = {
		.vadc = (&MODULE_VADC),
		.moduleFrequency = 100000000,
		.analogFrequency = 20000000,
		.digitalFrequency = 100000000,
		.startupCalibration = FALSE,
		.globalInputClass[0].sampleTime = 0.000001,
		.globalInputClass[0].resolution = IfxVadc_ChannelResolution_12bit,
		.globalInputClass[1].sampleTime = 0.000001,
		.globalInputClass[1].resolution = IfxVadc_ChannelResolution_12bit,
};

const IfxVadc_Adc_GroupConfig IfxVadc_adc_group_config[NUMBER_OF_USE_GROUP] = {
		{
				.groupId = IfxVadc_GroupId_0,
				.module = NULL_PTR,
				.arbiter = {
						.arbiterRoundLength = IfxVadc_ArbitrationRounds_4_slots,
						.requestSlotQueueEnabled = TRUE,
						.requestSlotScanEnabled = FALSE,
						.requestSlotBackgroundScanEnabled = FALSE,
				},
				.backgroundScanRequest = {
						.autoBackgroundScanEnabled = FALSE,
						.triggerConfig.gatingMode = IfxVadc_GatingMode_disabled,
						.triggerConfig.triggerMode = IfxVadc_TriggerMode_noExternalTrigger,
						.triggerConfig.gatingSource = IfxVadc_GatingSource_0,
						.triggerConfig.triggerSource = IfxVadc_TriggerSource_0,
						.requestSlotPrio = IfxVadc_RequestSlotPriority_lowest,
						.requestSlotStartMode = IfxVadc_RequestSlotStartMode_waitForStart,
				},
				.scanRequest = {
						.autoscanEnabled = FALSE,
						.triggerConfig.gatingMode = IfxVadc_GatingMode_disabled,
						.triggerConfig.triggerMode = IfxVadc_TriggerMode_noExternalTrigger,
						.triggerConfig.gatingSource = IfxVadc_GatingSource_0,
						.triggerConfig.triggerSource = IfxVadc_TriggerSource_0,
						.requestSlotPrio = IfxVadc_RequestSlotPriority_low,
						.requestSlotStartMode = IfxVadc_RequestSlotStartMode_waitForStart,
				},
				.queueRequest = {
						.flushQueueAfterInit = TRUE,
						.triggerConfig.gatingMode = IfxVadc_GatingMode_always,
						.triggerConfig.triggerMode = IfxVadc_TriggerMode_uponFallingEdge,
						.triggerConfig.gatingSource = IfxVadc_GatingSource_1,
						.triggerConfig.triggerSource = IfxVadc_TriggerSource_15,
						.requestSlotPrio = IfxVadc_RequestSlotPriority_highest,
						.requestSlotStartMode = IfxVadc_RequestSlotStartMode_cancelInjectRepeat,
				},
				.inputClass[0].sampleTime = 0.000001,
				.inputClass[0].resolution = IfxVadc_ChannelResolution_12bit,
				.inputClass[1].sampleTime = 0.000001,
				.inputClass[1].resolution = IfxVadc_ChannelResolution_12bit,
		},
		{
				.groupId = IfxVadc_GroupId_1,
				.module = NULL_PTR,
				.arbiter = {
						.arbiterRoundLength = IfxVadc_ArbitrationRounds_4_slots,
						.requestSlotQueueEnabled = TRUE,
						.requestSlotScanEnabled = FALSE,
						.requestSlotBackgroundScanEnabled = FALSE,
				},
				.backgroundScanRequest = {
						.autoBackgroundScanEnabled = FALSE,
						.triggerConfig.gatingMode = IfxVadc_GatingMode_disabled,
						.triggerConfig.triggerMode = IfxVadc_TriggerMode_noExternalTrigger,
						.triggerConfig.gatingSource = IfxVadc_GatingSource_0,
						.triggerConfig.triggerSource = IfxVadc_TriggerSource_0,
						.requestSlotPrio = IfxVadc_RequestSlotPriority_lowest,
						.requestSlotStartMode = IfxVadc_RequestSlotStartMode_waitForStart,
				},
				.scanRequest = {
						.autoscanEnabled = FALSE,
						.triggerConfig.gatingMode = IfxVadc_GatingMode_disabled,
						.triggerConfig.triggerMode = IfxVadc_TriggerMode_noExternalTrigger,
						.triggerConfig.gatingSource = IfxVadc_GatingSource_0,
						.triggerConfig.triggerSource = IfxVadc_TriggerSource_0,
						.requestSlotPrio = IfxVadc_RequestSlotPriority_low,
						.requestSlotStartMode = IfxVadc_RequestSlotStartMode_waitForStart,
				},
				.queueRequest = {
						.flushQueueAfterInit = TRUE,
						.triggerConfig.gatingMode = IfxVadc_GatingMode_always,
						.triggerConfig.triggerMode = IfxVadc_TriggerMode_uponFallingEdge,
						.triggerConfig.gatingSource = IfxVadc_GatingSource_1,
						.triggerConfig.triggerSource = IfxVadc_TriggerSource_15,
						.requestSlotPrio = IfxVadc_RequestSlotPriority_highest,
						.requestSlotStartMode = IfxVadc_RequestSlotStartMode_cancelInjectRepeat,
				},
				.inputClass[0].sampleTime = 0.000001,
				.inputClass[0].resolution = IfxVadc_ChannelResolution_12bit,
				.inputClass[1].sampleTime = 0.000001,
				.inputClass[1].resolution = IfxVadc_ChannelResolution_12bit,
		},
		{
				.groupId = IfxVadc_GroupId_2,
				.module = NULL_PTR,
				.arbiter = {
						.arbiterRoundLength = IfxVadc_ArbitrationRounds_4_slots,
						.requestSlotQueueEnabled = FALSE,
						.requestSlotScanEnabled = FALSE,
						.requestSlotBackgroundScanEnabled = FALSE,
				},
				.backgroundScanRequest = {
						.autoBackgroundScanEnabled = FALSE,
						.triggerConfig.gatingMode = IfxVadc_GatingMode_disabled,
						.triggerConfig.triggerMode = IfxVadc_TriggerMode_noExternalTrigger,
						.triggerConfig.gatingSource = IfxVadc_GatingSource_0,
						.triggerConfig.triggerSource = IfxVadc_TriggerSource_0,
						.requestSlotPrio = IfxVadc_RequestSlotPriority_lowest,
						.requestSlotStartMode = IfxVadc_RequestSlotStartMode_waitForStart,
				},
				.scanRequest = {
						.autoscanEnabled = FALSE,
						.triggerConfig.gatingMode = IfxVadc_GatingMode_disabled,
						.triggerConfig.triggerMode = IfxVadc_TriggerMode_noExternalTrigger,
						.triggerConfig.gatingSource = IfxVadc_GatingSource_0,
						.triggerConfig.triggerSource = IfxVadc_TriggerSource_0,
						.requestSlotPrio = IfxVadc_RequestSlotPriority_low,
						.requestSlotStartMode = IfxVadc_RequestSlotStartMode_waitForStart,
				},
				.queueRequest = {
						.flushQueueAfterInit = FALSE,
						.triggerConfig.gatingMode = IfxVadc_GatingMode_disabled,
						.triggerConfig.triggerMode = IfxVadc_TriggerMode_noExternalTrigger,
						.triggerConfig.gatingSource = IfxVadc_GatingSource_0,
						.triggerConfig.triggerSource = IfxVadc_TriggerSource_0,
						.requestSlotPrio = IfxVadc_RequestSlotPriority_highest,
						.requestSlotStartMode = IfxVadc_RequestSlotStartMode_cancelInjectRepeat,
				},
				.inputClass[0].sampleTime = 0.000001,
				.inputClass[0].resolution = IfxVadc_ChannelResolution_12bit,
				.inputClass[1].sampleTime = 0.000001,
				.inputClass[1].resolution = IfxVadc_ChannelResolution_12bit,
		},
		{
				.groupId = IfxVadc_GroupId_3,
				.module = NULL_PTR,
				.arbiter = {
						.arbiterRoundLength = IfxVadc_ArbitrationRounds_4_slots,
						.requestSlotQueueEnabled = TRUE,
						.requestSlotScanEnabled = FALSE,
						.requestSlotBackgroundScanEnabled = FALSE,
				},
				.backgroundScanRequest = {
						.autoBackgroundScanEnabled = FALSE,
						.triggerConfig.gatingMode = IfxVadc_GatingMode_disabled,
						.triggerConfig.triggerMode = IfxVadc_TriggerMode_noExternalTrigger,
						.triggerConfig.gatingSource = IfxVadc_GatingSource_0,
						.triggerConfig.triggerSource = IfxVadc_TriggerSource_0,
						.requestSlotPrio = IfxVadc_RequestSlotPriority_lowest,
						.requestSlotStartMode = IfxVadc_RequestSlotStartMode_waitForStart,
				},
				.scanRequest = {
						.autoscanEnabled = FALSE,
						.triggerConfig.gatingMode = IfxVadc_GatingMode_disabled,
						.triggerConfig.triggerMode = IfxVadc_TriggerMode_noExternalTrigger,
						.triggerConfig.gatingSource = IfxVadc_GatingSource_0,
						.triggerConfig.triggerSource = IfxVadc_TriggerSource_0,
						.requestSlotPrio = IfxVadc_RequestSlotPriority_low,
						.requestSlotStartMode = IfxVadc_RequestSlotStartMode_waitForStart,
				},
				.queueRequest = {
						.flushQueueAfterInit = TRUE,
						.triggerConfig.gatingMode = IfxVadc_GatingMode_always,
						.triggerConfig.triggerMode = IfxVadc_TriggerMode_uponFallingEdge,
						.triggerConfig.gatingSource = IfxVadc_GatingSource_1,
						.triggerConfig.triggerSource = IfxVadc_TriggerSource_15,
						.requestSlotPrio = IfxVadc_RequestSlotPriority_highest,
						.requestSlotStartMode = IfxVadc_RequestSlotStartMode_cancelInjectRepeat,
				},
				.inputClass[0].sampleTime = 0.000001,
				.inputClass[0].resolution = IfxVadc_ChannelResolution_12bit,
				.inputClass[1].sampleTime = 0.000001,
				.inputClass[1].resolution = IfxVadc_ChannelResolution_12bit,
		},
};

const AppVadc_AnalogInput_cfg IfxVadc_cfg_adc_channel[AppVadc_ChannelCount] = {
		{ // AN0, U
				.groupId = IfxVadc_GroupId_0,
				.hwChannel = {
				        .channelId           = IfxVadc_ChannelId_0,
				        .group               = NULL_PTR,
				        .inputClass          = IfxVadc_InputClasses_group0,
				        .reference           = IfxVadc_ChannelReference_standard,
				        .resultRegister      = IfxVadc_ChannelResult_0,
				        .globalResultUsage   = FALSE,
				        .lowerBoundary       = IfxVadc_BoundarySelection_group0,
				        .upperBoundary       = IfxVadc_BoundarySelection_group0,
				        .boundaryMode        = IfxVadc_BoundaryExtension_standard,
				        .limitCheck          = IfxVadc_LimitCheck_noCheck,
				        .synchonize          = FALSE,
				        .backgroundChannel   = FALSE,
				        .rightAlignedStorage = FALSE,
				        .resultPriority      = 0,
				        .resultSrcNr         = IfxVadc_SrcNr_group0,
				        .resultServProvider  = IfxSrc_Tos_cpu0,
				        .channelPriority     = 0,
				        .channelSrcNr        = IfxVadc_SrcNr_group0,
				        .channelServProvider = IfxSrc_Tos_cpu0
				},
				.coversionSetup =
				{
					.requestSource = IfxVadc_RequestSource_queue,
					.priority	= 1,
					.refill 	= TRUE,
					.trigger    = TRUE,
				},
				.limits = {
						.min = APPVADC_CFG_IMOTOR_MIN,
						.max = APPVADC_CFG_IMOTOR_MAX,
						.status = AppVadc_LimitsStatus_Ok,
						.onOutOfRange	= NULL_PTR,
						.object			= NULL_PTR,
						.info			= 0
				},
				.gain	=	APPVADC_CFG_IMOTOR_GAIN,
				.offset	= 	APPVADC_CFG_IMOTOR_OFFSET,
		},
		{ // AN8 VRO
				.groupId = IfxVadc_GroupId_1,
				.hwChannel = {
				        .channelId           = IfxVadc_ChannelId_0,
				        .group               = NULL_PTR,
				        .inputClass          = IfxVadc_InputClasses_group0,
				        .reference           = IfxVadc_ChannelReference_standard,
				        .resultRegister      = IfxVadc_ChannelResult_0,
				        .globalResultUsage   = FALSE,
				        .lowerBoundary       = IfxVadc_BoundarySelection_group0,
				        .upperBoundary       = IfxVadc_BoundarySelection_group0,
				        .boundaryMode        = IfxVadc_BoundaryExtension_standard,
				        .limitCheck          = IfxVadc_LimitCheck_noCheck,
				        .synchonize          = FALSE,
				        .backgroundChannel   = FALSE,
				        .rightAlignedStorage = FALSE,
				        .resultPriority      = INTERRUPT_VADC_RESULT_GROUP0,
				        .resultSrcNr         = IfxVadc_SrcNr_group0,
				        .resultServProvider  = IfxSrc_Tos_cpu0,
				        .channelPriority     = 0,
				        .channelSrcNr        = IfxVadc_SrcNr_group0,
				        .channelServProvider = IfxSrc_Tos_cpu0
				},
				.coversionSetup =
				{
					.requestSource = IfxVadc_RequestSource_queue,
					.priority	= 2,
					.refill 	= TRUE,
					.trigger    = FALSE,
				},
				.limits = {
						.min = APPVADC_CFG_VMOTOR_MIN,
						.max = APPVADC_CFG_VMOTOR_MAX,
						.status = AppVadc_LimitsStatus_Ok,
						.onOutOfRange	= NULL_PTR,
						.object			= NULL_PTR,
						.info			= 0
				},
				.gain	=	APPVADC_CFG_VMOTOR_GAIN,
				.offset	= 	APPVADC_CFG_VMOTOR_OFFSET,
		},
		{ // AN24 V
				.groupId = IfxVadc_GroupId_3,
				.hwChannel = {
				        .channelId           = IfxVadc_ChannelId_0,
				        .group               = NULL_PTR,
				        .inputClass          = IfxVadc_InputClasses_group0,
				        .reference           = IfxVadc_ChannelReference_standard,
				        .resultRegister      = IfxVadc_ChannelResult_0,
				        .globalResultUsage   = FALSE,
				        .lowerBoundary       = IfxVadc_BoundarySelection_group0,
				        .upperBoundary       = IfxVadc_BoundarySelection_group0,
				        .boundaryMode        = IfxVadc_BoundaryExtension_standard,
				        .limitCheck          = IfxVadc_LimitCheck_noCheck,
				        .synchonize          = FALSE,
				        .backgroundChannel   = FALSE,
				        .rightAlignedStorage = FALSE,
				        .resultPriority      = 0,
				        .resultSrcNr         = IfxVadc_SrcNr_group0,
				        .resultServProvider  = IfxSrc_Tos_cpu0,
				        .channelPriority     = 0,
				        .channelSrcNr        = IfxVadc_SrcNr_group0,
				        .channelServProvider = IfxSrc_Tos_cpu0
				},
				.coversionSetup =
				{
					.requestSource = IfxVadc_RequestSource_queue,
					.priority	= 1,
					.refill 	= TRUE,
					.trigger    = TRUE
				},
				.limits = {
						.min = APPVADC_CFG_IMOTOR_MIN,
						.max = APPVADC_CFG_IMOTOR_MAX,
						.status = AppVadc_LimitsStatus_Ok,
						.onOutOfRange	= NULL_PTR,
						.object			= NULL_PTR,
						.info			= 0
				},
				.gain	=	APPVADC_CFG_IMOTOR_GAIN,
				.offset	= 	APPVADC_CFG_IMOTOR_OFFSET,
		},
};

AppVadc_Kernel g_appVadc_kernel;

void AppVadc_init(void)
{
	uint8 i,j;
	uint8 groupId;
	IfxVadc_Adc_GroupConfig		groupConfig;
	IfxVadc_Adc_ChannelConfig 	channelConfig;

	AppVadc_queuedMode lcl_queued[NUMBER_OF_USE_GROUP];
	uint32 lcl_scanSource[NUMBER_OF_USE_GROUP] = {0};

	for(i=0; i< 9; i++)
	{
		for(j=0;j<NUMBER_OF_USE_GROUP;j++)
		{
			lcl_queued[j].channelIndex[i] = 0;
			lcl_queued[j].used[i] = 0;
			lcl_queued[j].options[i] = 0;
		}
	}

	// initialize VADC Module
	IfxVadc_Adc_initModule(&g_appVadc_kernel.module, &IfxVadc_adc_module_config);

	// initialize Group
	for(i = 0; i < NUMBER_OF_USE_GROUP; i++)
	{
		groupConfig = IfxVadc_adc_group_config[i];
		groupConfig.module =& g_appVadc_kernel.module;
		IfxVadc_Adc_initGroup(&g_appVadc_kernel.group[i], &groupConfig);
	}

	// initialize Vadc Channels

	for(i = 0; i < AppVadc_ChannelCount; i++)
	{
		groupId = IfxVadc_cfg_adc_channel[i].groupId;
		channelConfig = IfxVadc_cfg_adc_channel[i].hwChannel;
		channelConfig.group = &g_appVadc_kernel.group[groupId];
		IfxVadc_Adc_initChannel(&g_appVadc_kernel.channel[i].input, &channelConfig);
		g_appVadc_kernel.channel[i].limits = IfxVadc_cfg_adc_channel[i].limits;
		g_appVadc_kernel.channel[i].gain = IfxVadc_cfg_adc_channel[i].gain;
		g_appVadc_kernel.channel[i].offset = IfxVadc_cfg_adc_channel[i].offset;
		g_appVadc_kernel.channel[i].rawvalue = 0U;
		g_appVadc_kernel.channel[i].value = 0.0;
		switch(IfxVadc_cfg_adc_channel[i].coversionSetup.requestSource)
		{
		case IfxVadc_RequestSource_queue:
			if(groupId<NUMBER_OF_USE_GROUP)	// for local Group Ids
			{
				uint16 options = 0;
				lcl_queued[groupId].channelIndex[IfxVadc_cfg_adc_channel[i].coversionSetup.priority] = i;	// Set channel
				lcl_queued[groupId].used[IfxVadc_cfg_adc_channel[i].coversionSetup.priority] = 1;	// Set Indicator
				if(IfxVadc_cfg_adc_channel[i].coversionSetup.refill == TRUE)
				{
					options = IFXVADC_QUEUE_REFILL;
				}
				if(IfxVadc_cfg_adc_channel[i].coversionSetup.trigger == TRUE)
				{
					options |= IFXVADC_QUEUE_EXT_TRIGGER;
				}
				lcl_queued[groupId].options[IfxVadc_cfg_adc_channel[i].coversionSetup.priority]	= options;	// store the options for this channel
			}
		break;
		case IfxVadc_RequestSource_scan:
			if(groupId<NUMBER_OF_USE_GROUP)	// for local Group Ids
				lcl_scanSource[groupId] |= 0x1<<channelConfig.channelId;
		break;
		case IfxVadc_RequestSource_background:
		break;
		default: break;
		}
	}

	// Fill queue with requested channels, Oversampling for Current measurement

		// Add Oversampling of I_U at Group 0
		IfxVadc_Adc_addToQueue(&g_appVadc_kernel.channel[AppVadc_Ch_I_U].input, IFXVADC_QUEUE_REFILL|IFXVADC_QUEUE_EXT_TRIGGER);	//  Trigger just refill
		IfxVadc_Adc_addToQueue(&g_appVadc_kernel.channel[AppVadc_Ch_I_U].input, IFXVADC_QUEUE_REFILL);	// No Trigger just refill
		IfxVadc_Adc_addToQueue(&g_appVadc_kernel.channel[AppVadc_Ch_I_U].input, IFXVADC_QUEUE_REFILL);	// No Trigger just refill
		IfxVadc_Adc_addToQueue(&g_appVadc_kernel.channel[AppVadc_Ch_I_U].input, IFXVADC_QUEUE_REFILL);	// No Trigger just refill

		// Add Oversampling of I_V at Group 1
		IfxVadc_Adc_addToQueue(&g_appVadc_kernel.channel[AppVadc_Ch_I_V].input, IFXVADC_QUEUE_REFILL|IFXVADC_QUEUE_EXT_TRIGGER);	//  Trigger just refill
		IfxVadc_Adc_addToQueue(&g_appVadc_kernel.channel[AppVadc_Ch_I_V].input, IFXVADC_QUEUE_REFILL);	// No Trigger just refill
		IfxVadc_Adc_addToQueue(&g_appVadc_kernel.channel[AppVadc_Ch_I_V].input, IFXVADC_QUEUE_REFILL);	// No Trigger just refill
		IfxVadc_Adc_addToQueue(&g_appVadc_kernel.channel[AppVadc_Ch_I_V].input, IFXVADC_QUEUE_REFILL);	// No Trigger just refill

		// Add Oversampling of I_VRO at Group 0
		IfxVadc_Adc_addToQueue(&g_appVadc_kernel.channel[AppVadc_Ch_V_Vro].input, IFXVADC_QUEUE_REFILL);	// No Trigger just refill

		// Enable Datareduction
		g_appVadc_kernel.channel[AppVadc_Ch_I_U].input.group->module.vadc->G[0].RCR[0].B.DRCTR = 3; //Accumulate 4 result
		g_appVadc_kernel.channel[AppVadc_Ch_I_U].input.group->module.vadc->G[0].RCR[0].B.DMM = 0; //Standard data reduction

		g_appVadc_kernel.channel[AppVadc_Ch_I_V].input.group->module.vadc->G[1].RCR[0].B.DRCTR = 3; //Accumulate 4 result
		g_appVadc_kernel.channel[AppVadc_Ch_I_V].input.group->module.vadc->G[1].RCR[0].B.DMM = 0;


	// Fill Scan source with requested channels
	for(j=0; j < NUMBER_OF_USE_GROUP;j++)
	{
		IfxVadc_Adc_setScan(&g_appVadc_kernel.group[j], lcl_scanSource[j], lcl_scanSource[j]);
	}

}


float32 AppVadc_limits_float32_Execute(AppVadc_Limits_1_float32* limits, float32 in)
{
    if (in > limits->max)
    {
        limits->status = AppVadc_LimitsStatus_Max;
        if(limits->onOutOfRange != NULL_PTR)
        {
        	limits->onOutOfRange(limits->object, limits->status,limits->info);
        }
    }
    else if (in < limits->min)
    {
        limits->status = AppVadc_LimitsStatus_Min;
        if(limits->onOutOfRange != NULL_PTR)
		{
			limits->onOutOfRange(limits->object, limits->status,limits->info);
		}
    }
    else
    {
        limits->status = AppVadc_LimitsStatus_Ok;
    }
    return in;
}


float32 AppVadc_updateAnalogInput(AppVadc_AnalogInput_1 *input)
{

	float32 value;
	uint32 rawValue;
	rawValue = IfxVadc_Adc_getResult(&input->input).B.RESULT;

	// Scale Input
	value = ((float32)input->gain * rawValue + input->offset);
	 /* Check limits */
	value = AppVadc_limits_float32_Execute(&input->limits, value);
	/* Store value */
	input->rawvalue = rawValue;
	input->value = value;
	return value;
}


float32 AppVadc_updateAnalogInput_DRC(AppVadc_AnalogInput_1 *input)
{

	float32 value;
	uint32 rawValue;
	rawValue = IfxVadc_Adc_getResult(&input->input).B.RESULT>>2;

	// Scale Input
	value = ((float32)input->gain * rawValue + input->offset);
	 /* Check limits */
	value = AppVadc_limits_float32_Execute(&input->limits, value);
	/* Apply filter
	if (Input->FilterEnabled == TRUE)
	{
		value = LowPass_PT1_Do(&Input->Filter, value);
	}
	*/
	/* Store value */
	input->rawvalue = rawValue;
	input->value = value;
	return value;
}


void vadc_conversionEndGroup0(void)
{
	__enable();
	AppVadc_updateAnalogInput(&g_appVadc_kernel.channel[AppVadc_Ch_V_Vro]);
	AppVadc_updateAnalogInput_DRC(&g_appVadc_kernel.channel[AppVadc_Ch_I_U]);
	AppVadc_updateAnalogInput_DRC(&g_appVadc_kernel.channel[AppVadc_Ch_I_V]);

	TQC_startMotor(&g_motor);

	if(IsCurrentSensorCalibrated(&g_motor))
	{
		g_motor.currents.u = g_motor.analogInputs.currentA->value;
		g_motor.currents.v = g_motor.analogInputs.currentB->value;
		g_motor.currents.w = -(g_motor.currents.u + g_motor.currents.v);

		TQC_FocStep(&g_motor, &g_motor.currents, 0.0);

	}else
	{
		ZeroCurrentSensor(&g_motor,g_motor.analogInputs.currentA,g_motor.analogInputs.currentB,g_motor.analogInputs.currentB,g_motor.analogInputs.sensorOffset);
	}

}


AppVadc_AnalogInput_1* AppVadc_getCurrentPhaseU_object(void)
{
	return(&g_appVadc_kernel.channel[AppVadc_Ch_I_U]);
}

AppVadc_AnalogInput_1* AppVadc_getCurrentPhaseV_object(void)
{
	return(&g_appVadc_kernel.channel[AppVadc_Ch_I_V]);
}

AppVadc_AnalogInput_1* AppVadc_getCurrentOffset_object(void)
{
	return(&g_appVadc_kernel.channel[AppVadc_Ch_V_Vro]);
}
