/*
 * FOC.h
 *
 *  Created on: 2021. 3. 11.
 *      Author: User
 */

#ifndef MOTOR_CONTROL_FOC_H_
#define MOTOR_CONTROL_FOC_H_

#include "Ifx_Types.h"
#include "PI.h"
#include "Transformation.h"

typedef struct {
	cfloat32        ref;             /**< @brief FOC reference currents in the dq frame */
	cfloat32        limit;           /**< @brief FOC reference current limits */
    float32            limitAmpl;       /**< @brief Iq and Id resultant limits */
    TPic               piId;            /**< @brief PI controller for the direct current */
    TPic               piIq;            /**< @brief PI controller for the quadrature current */
    cfloat32        nfo_iab;         /**< @brief output of the reverse clarke transformation */
    cfloat32        nfo_mab;         /**< @brief output of the reverse park transformation */
    cfloat32        mab;         /**< @brief output of the reverse park transformation */
    cfloat32        nfo_mdq;              /**< @brief output of the park transformation (debug information) */
} TFoc;

boolean FOC_Init(TFoc *foc);
void FOC_SetIq(TFoc *foc, float32 iq);
float32 FOC_GetIq(TFoc *foc);
void FOC_SetId(TFoc *foc, float32 id);
float32 FOC_GetId(TFoc *foc);
void FOC_SetIqLimit(TFoc *foc, float32 limit);
float32 FOC_GetIqLimit(TFoc *foc);
void FOC_SetIdLimit(TFoc *foc, float32 limit);
float32 FOC_GetIdLimit(TFoc *foc);
cfloat32 FOC_Do(TFoc *foc, sint32 electricalAngle, T3Phase *currents);
void FOC_Reset(TFoc *foc);
IFX_INLINE float32 FOC_GetIqActual(TFoc* foc) { return foc->nfo_mdq.imag; }
IFX_INLINE float32 FOC_GetIdActual(TFoc* foc) { return foc->nfo_mdq.real; }

#endif /* MOTOR_CONTROL_FOC_H_ */
