/*
 * VelocityControl.c
 *
 *  Created on: 2021. 3. 11.
 *      Author: User
 */

#include "VelocityControl.h"

/** @brief Execute the speed PI controller
 *
 * @param VelocityControl Specifies the velocity control object.
 * @param Speed Specifies the current speed.
 *
 * @return the speed controller output.
 * @see Pic()
 * @ingroup app_velocity_control
 */
float32 VelocityControl_Do(VelocityControl *velocityControl, float32 speed)
{
	float32 result;
    if (velocityControl->enabled != FALSE)
    {
        result = PIC_Do(&velocityControl->pi, velocityControl->ref - speed);
    }
    else
    {
        result = velocityControl->pi.uk;
    }
    return result;
}

/** @brief Initialize the velocity control object
 *
 * @param VelocityControl Specifies the velocity control object.
 *
 * @return None.
 * @see PIC_Init()
 * @ingroup app_velocity_control
 */
void VelocityControl_Init(VelocityControl *velocityControl)
{
    PIC_Init(&velocityControl->pi);
}


