/*
 * TLE9180.c
 *
 *  Created on: 2021. 3. 10.
 *      Author: User
 */

#include "TLE9180.h"

#define TIMER_COUNT             (11)                                /**< \internal \brief number of timer values defined */
#define TIMER_INDEX_10NS        (0)                                 /**< \internal \brief Index of the time value 10ns*/
#define TIMER_INDEX_100NS       (1)                                 /**< \internal \brief Index of the time value 100ns*/
#define TIMER_INDEX_1US         (2)                                 /**< \internal \brief Index of the time value 1us*/
#define TIMER_INDEX_10US        (3)                                 /**< \internal \brief Index of the time value 10us*/
#define TIMER_INDEX_100US       (4)                                 /**< \internal \brief Index of the time value 100us*/
#define TIMER_INDEX_1MS         (5)                                 /**< \internal \brief Index of the time value 1ms*/
#define TIMER_INDEX_10MS        (6)                                 /**< \internal \brief Index of the time value 10ms*/
#define TIMER_INDEX_100MS       (7)                                 /**< \internal \brief Index of the time value 100ms*/
#define TIMER_INDEX_1S          (8)                                 /**< \internal \brief Index of the time value 1s*/
#define TIMER_INDEX_10S         (9)                                 /**< \internal \brief Index of the time value 10s*/
#define TIMER_INDEX_100S        (10)                                /**< \internal \brief Index of the time value 100s*/

#define TimeConst_0s            ((Ifx_TickTime)0)                          /**< \brief time constant equal to 1s */
#define TimeConst_10ns          (LocalTimeConst[TIMER_INDEX_10NS])       /**< \brief time constant equal to 10ns */
#define TimeConst_100ns         (LocalTimeConst[TIMER_INDEX_100NS])      /**< \brief time constant equal to 100ns */
#define TimeConst_1us           (LocalTimeConst[TIMER_INDEX_1US])        /**< \brief time constant equal to 1us */
#define TimeConst_10us          (LocalTimeConst[TIMER_INDEX_10US])       /**< \brief time constant equal to 10us */
#define TimeConst_100us         (LocalTimeConst[TIMER_INDEX_100US])      /**< \brief time constant equal to 100us */
#define TimeConst_1ms           (LocalTimeConst[TIMER_INDEX_1MS])        /**< \brief time constant equal to 1ms */
#define TimeConst_10ms          (LocalTimeConst[TIMER_INDEX_10MS])       /**< \brief time constant equal to 10ms */
#define TimeConst_100ms         (LocalTimeConst[TIMER_INDEX_100MS])      /**< \brief time constant equal to 100ms */
#define TimeConst_1s            (LocalTimeConst[TIMER_INDEX_1S])         /**< \brief time constant equal to 1s */
#define TimeConst_10s           (LocalTimeConst[TIMER_INDEX_10S])        /**< \brief time constant equal to 10s */
#define TimeConst_100s          (LocalTimeConst[TIMER_INDEX_100S])       /**< \brief time constant equal to 100s */

uint32 TLE9180RxBuffer[68]; // only debug
Ifx_TickTime LocalTimeConst[TIMER_COUNT];
TLE9180 TLE9180Handler;

const TLE9180_Config cfg_Tle9180 =
{
    .size       = 8192,
    .inhibit	= {&MODULE_P10,6u,Ifx_ActiveState_low},
    .enable	    = {&MODULE_P20,10u,Ifx_ActiveState_high},
    .safeOff	= {&MODULE_P20,9u,Ifx_ActiveState_low},
    .error		= {&MODULE_P15,4u,Ifx_ActiveState_low}
};

static void TLE9180_initLocalTime(void);

boolean TLE9180_loadStartupConfiguration(void) {

	boolean result = FALSE;

	uint32 sscBuffer[13] = {
			0x818104,
			0x820F00,
			0x867006,
			0x879A06,
			0x883201,
			0x8A2A03,
			0x8B4A03,
		    0x932A05,
			0x80AC02,
			0xA04403,
			0xA14407,
			0xA24400,
			0xA39F00};

	// enhanced configuration B Step

	while(result!=TRUE)
	{
		result = (SpiIf_exchange(TLE9180Handler.sscChannel, &sscBuffer[0], &TLE9180Handler.sscReceiveBuffer[0], 13) == SpiIf_Status_ok);
	}

	return(result);
}

boolean TLE9180_readRegister(void)
{
	boolean result = TRUE;

	uint32 sscBuffer[12] = {
			0x260004,
			0x270000,
			0x280006,
			0x290002,
			0x2A0005,
			0x2B0001,
			0x2C0000,
			0x2D0004,
			0x2E0003,
			0x2F0007,
			0x300004,
			0x260004};
	// error Registers

	result = (SpiIf_exchange(TLE9180Handler.sscChannel, &sscBuffer[TLE9180Handler.registerCounter], &TLE9180Handler.sscReceiveBuffer[38 + TLE9180Handler.registerCounter], 4) == SpiIf_Status_ok);
	if(result != FALSE)
	{
		TLE9180Handler.registerCounter+=4;
		if(TLE9180Handler.registerCounter == 12){ TLE9180Handler.registerCounter = 0; }
	}

	return(result);
}

static void TLE9180_initLocalTime(void) {

    sint32 Fsys = IfxStm_getFrequency(BSP_DEFAULT_TIMER);

    LocalTimeConst[TIMER_INDEX_10NS]  = Fsys / (1000000000 / 10);
    LocalTimeConst[TIMER_INDEX_100NS] = Fsys / (1000000000 / 100);
    LocalTimeConst[TIMER_INDEX_1US]   = Fsys / (1000000 / 1);
    LocalTimeConst[TIMER_INDEX_10US]  = Fsys / (1000000 / 10);
    LocalTimeConst[TIMER_INDEX_100US] = Fsys / (1000000 / 100);
    LocalTimeConst[TIMER_INDEX_1MS]   = Fsys / (1000 / 1);
    LocalTimeConst[TIMER_INDEX_10MS]  = Fsys / (1000 / 10);
    LocalTimeConst[TIMER_INDEX_100MS] = Fsys / (1000 / 100);
    LocalTimeConst[TIMER_INDEX_1S]    = Fsys * (1);
    LocalTimeConst[TIMER_INDEX_10S]   = Fsys * (10);
    LocalTimeConst[TIMER_INDEX_100S]  = Fsys * (100);
}

void TLE9180_init(void) {

	SPI3_init();
	TLE9180_initLocalTime();

	Ifx_TickTime time = getDeadLine(TimeConst_1ms);

    TLE9180Handler.size = cfg_Tle9180.size;

    if(cfg_Tle9180.inhibit.port != NULL_PTR)
    {
    	TLE9180Handler.inhibit = cfg_Tle9180.inhibit;
    	IfxPort_setPinMode(TLE9180Handler.inhibit.port, TLE9180Handler.inhibit.pinIndex, IfxPort_Mode_outputPushPullGeneral);
    }
    if(cfg_Tle9180.enable.port != NULL_PTR)
    {
       	TLE9180Handler.enable = cfg_Tle9180.enable;
       	IfxPort_setPinMode(TLE9180Handler.enable.port, TLE9180Handler.enable.pinIndex, IfxPort_Mode_outputPushPullGeneral);
    }
    if(cfg_Tle9180.safeOff.port != NULL_PTR)
    {
		TLE9180Handler.safeOff = cfg_Tle9180.safeOff;
		IfxPort_setPinMode(TLE9180Handler.safeOff.port, TLE9180Handler.safeOff.pinIndex, IfxPort_Mode_outputPushPullGeneral);
    }
    if(cfg_Tle9180.error.port != NULL_PTR)
	{
		TLE9180Handler.error = cfg_Tle9180.error;
		IfxPort_setPinMode(TLE9180Handler.error.port, TLE9180Handler.error.pinIndex, IfxPort_Mode_inputNoPullDevice);
	}

    TLE9180_deactivateInhibit(&TLE9180Handler);
    while(isDeadLine(time) != TRUE);
    time = getDeadLine(TimeConst_1s);
    TLE9180_activateInhibit(&TLE9180Handler);
    TLE9180Handler.sscChannel = &SPI3ChannelHandler.base;
    while(isDeadLine(time) != TRUE);	// Wait
    time = getDeadLine(TimeConst_1ms);
    TLE9180_deactivateInhibit(&TLE9180Handler);
    while(isDeadLine(time) != TRUE);	// Wait
    TLE9180_deactivateSafeOff(&TLE9180Handler);
}
