/*
 * TLE9180.h
 *
 *  Created on: 2021. 3. 10.
 *      Author: User
 */

#ifndef MOTOR_DEVICE_TLE9180_H_
#define MOTOR_DEVICE_TLE9180_H_

#include "SPI.h"
#include "PWM.h"
#include "STM.h"

typedef struct
{
	Ifx_P *port;
	uint8 pinIndex;
	Ifx_ActiveState activeState;
}TLE9180_OutPin;

typedef struct
{
	Ifx_P *port;
	uint8 pinIndex;
	Ifx_ActiveState activeState;
}TLE9180_InPin;

typedef struct{
	uint32	crc3:3;				/** \brief	[0..2] crc3	*/
	uint32	reserved_3:1;		/** \brief	[3]	reserved*/
	uint32	data:8;				/** \brief	[4..11]	data*/
	uint32	address:7;			/** \brief	[12..19]	address field*/
	uint32	specialEvent:1;		/** \brief	[19]	special event flag*/
	uint32	spiError:1;			/** \brief	[20]	spi error flag*/
	uint32	configValid:1;		/** \brief	[21]	configuration valid flag*/
	uint32	warning:1;			/** \brief	[22]	warning flag*/
	uint32	error:1;			/** \brief	[23]	error flag*/
	uint32	reserved_24:8;			/** \brief	[24..31]	reserved area*/
}TLE9180_SscReceive_bits;

typedef union
{
    /** \brief Unsigned access */
    uint32 U;
    /** \brief Bitfield access */
    TLE9180_SscReceive_bits B;
} TLE9180_SscReceive;

typedef struct
{
	uint32	size;
	//IfxQspi_Spi_ChannelConfig cfg_sscChannel;
	TLE9180_OutPin	inhibit;
	TLE9180_OutPin	enable;
	TLE9180_OutPin	safeOff;
	TLE9180_InPin	error;
}TLE9180_Config;

typedef enum
{
	TLE9180_notPossible = 0,
	TLE9180_LSPossible = 1,
	TLE9180_HSPossible = 2
}IsPossible;

typedef struct
{
	SpiIf_Ch  *sscChannel;
	TLE9180_SscReceive	sscReceiveBuffer[68];
	uint32	size;
	uint32	registerCounter;
	TLE9180_OutPin	inhibit;
	TLE9180_OutPin	enable;
	TLE9180_OutPin	safeOff;
	TLE9180_InPin	error;

}TLE9180;

extern TLE9180 TLE9180Handler;

IFX_EXTERN void TLE9180_init(void);
IFX_EXTERN boolean TLE9180_loadStartupConfiguration(void);
boolean TLE9180_readRegister(void);

IFX_INLINE void TLE9180_deactivateInhibit(TLE9180* handle)
{
	IfxPort_setPinState(handle->inhibit.port, handle->inhibit.pinIndex,(handle->inhibit.activeState == (Ifx_ActiveState_high)? IfxPort_State_low : IfxPort_State_high));
}

IFX_INLINE void TLE9180_activateInhibit(TLE9180* handle)
{
	IfxPort_setPinState(handle->inhibit.port, handle->inhibit.pinIndex,(handle->inhibit.activeState == (Ifx_ActiveState_high)? IfxPort_State_high : IfxPort_State_low));
}

IFX_INLINE void TLE9180_activateEnable(TLE9180* handle)
{
	IfxPort_setPinState(handle->enable.port, handle->enable.pinIndex,(handle->enable.activeState == (Ifx_ActiveState_high)? IfxPort_State_high : IfxPort_State_low));
}

IFX_INLINE void TLE9180_deactivateEnable(TLE9180* handle)
{
	IfxPort_setPinState(handle->enable.port, handle->enable.pinIndex,(handle->enable.activeState == (Ifx_ActiveState_high)? IfxPort_State_low : IfxPort_State_high));
}

IFX_INLINE void TLE9180_activateSafeOff(TLE9180* handle)
{
	IfxPort_setPinState(handle->safeOff.port, handle->safeOff.pinIndex,(handle->safeOff.activeState == (Ifx_ActiveState_high)? IfxPort_State_high : IfxPort_State_low));
}

IFX_INLINE void TLE9180_deactivateSafeOff(TLE9180* handle)
{
	IfxPort_setPinState(handle->safeOff.port, handle->safeOff.pinIndex,(handle->safeOff.activeState == (Ifx_ActiveState_high)? IfxPort_State_low : IfxPort_State_high));
}

IFX_INLINE boolean TLE9180_getErrorState(TLE9180* handle)
{
	if(handle->error.activeState == (Ifx_ActiveState_high))
		return(IfxPort_getPinState(handle->error.port, handle->error.pinIndex) == TRUE);
	else
		return(IfxPort_getPinState(handle->error.port, handle->error.pinIndex) ==FALSE);
}
#endif /* MOTOR_DEVICE_TLE9180_H_ */
