/*
 * SVM.c
 *
 *  Created on: 2021. 3. 11.
 *      Author: User
 */

#include "SVM.h"
#include "Tables.h"

static uint8 SVM_getSector(cfloat32 m) {

	float32 x;
	uint8 sector;

	x = m.imag * (float32) IFX_ONE_OVER_SQRT_THREE;
	if(m.imag > 0) {

		if(m.real > 0) {

			// quadrant 1
			if(x < m.real) {
				sector = 0;
			}
			else {
				sector = 1;
			}
		}
		else {

			// quadrant 2
			if(x < -m.real) {
				sector = 2;
			}
			else {
				sector = 1;
			}
		}
	}
	else {
		if (m.real < 0) {
			// quadrant 3
			if(x < m.real) {
				sector = 4;
			}
			else {
				sector = 3;
			}
		}
		else {
			// quadrant 4
			if(x < -m.real) {

				sector = 4;
			}
			else {

				sector = 5;
			}
		}
	}

	return sector;
}

uint8 SVM_modulate(cfloat32 m, Ifx_TimerValue period, Ifx_TimerValue* tOn) {

	uint8 sector;
	Ifx_TimerValue tk, tk1;
	Ifx_TimerValue ts, tm, tb;
	Ifx_TimerValue halfPeriod;

	sector = SVM_getSector(m);

	tk = ((sinCosVector[((sector + 1)*2)+0] * m.real) - (sinCosVector[((sector + 1)*2)+1] * m.imag)) * (sint16)period;
	tk1 = ((sinCosVector[((sector    )*2)+1]* m.imag) - (sinCosVector[((sector    )*2)+0] * m.real)) * (sint16)period;

    if ((sector & 0x1) != 0)
    {
    	Ifx_TimerValue temp;
        temp = tk;
        tk = tk1;
        tk1 = temp;
    }

    halfPeriod = period >> 1;
    ts = __saturate((halfPeriod  - tk) - tk1, 0, period);
    tm = __saturate((halfPeriod  - tk) + tk1, 0, period);
    tb = __saturate((halfPeriod  + tk) + tk1, 0, period);

    switch (sector)
    {
        case 0:
        	tOn[0] = tb;
        	tOn[1] = tm;
        	tOn[2] = ts;
            break;
        case 1:
        	tOn[0] = tm;
        	tOn[1] = tb;
        	tOn[2] = ts;
            break;
        case 2:
        	tOn[0] = ts;
        	tOn[1] = tb;
        	tOn[2] = tm;
            break;
        case 3:
        	tOn[0] = ts;
        	tOn[1] = tm;
        	tOn[2] = tb;
            break;
        case 4:
        	tOn[0] = tm;
        	tOn[1] = ts;
        	tOn[2] = tb;
            break;
        case 5:
        	tOn[0] = tb;
        	tOn[1] = ts;
        	tOn[2] = tm;
            break;
        default:
            break;
    }


    return(sector);
}
